@@ -75,7 +75,7 @@ DDockMenu::DDockMenu(DDockMenu *parent)
         if (geometry().contains(p)) {
             m_menuContent->processButtonClick(p);
         } else {
-            qDebug() << "window deactivate, destory menu";
+            qDebug() << "window deactivate, destroy menu";
             destroyAll();
         }
     });
@@ -83,6 +83,7 @@ DDockMenu::DDockMenu(DDockMenu *parent)
 
 DDockMenu::~DDockMenu()
 {
+    m_monitor->unregisterRegion();
     setVisible(false);
     releaseFocus();
     releaseKeyboard();
@@ -140,7 +141,7 @@ bool DDockMenu::event(QEvent *event)
         {
             activateWindow();
         } else {
-            qDebug() << "window deactivate, destory menu";
+            qDebug() << "window deactivate, destroy menu";
             destroyAll();
         }
     }
@@ -169,7 +170,6 @@ void DDockMenu::hideEvent(QHideEvent *event)
 {
     DArrowRectangle::hideEvent(event);
 
-    Q_ASSERT(m_monitor->registered());
     m_monitor->unregisterRegion();
     releaseKeyboard();
 }
